@@ -25,32 +25,29 @@ class ListVideoAudiosRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ListVideoAudios','imm')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Project(self):
+	def get_Project(self): # String
 		return self.get_query_params().get('Project')
 
-	def set_Project(self,Project):
-		self.add_query_param('Project',Project)
-
-	def get_VideoUri(self):
+	def set_Project(self, Project):  # String
+		self.add_query_param('Project', Project)
+	def get_VideoUri(self): # String
 		return self.get_query_params().get('VideoUri')
 
-	def set_VideoUri(self,VideoUri):
-		self.add_query_param('VideoUri',VideoUri)
-
-	def get_Marker(self):
+	def set_VideoUri(self, VideoUri):  # String
+		self.add_query_param('VideoUri', VideoUri)
+	def get_Marker(self): # String
 		return self.get_query_params().get('Marker')
 
-	def set_Marker(self,Marker):
-		self.add_query_param('Marker',Marker)
-
-	def get_SetId(self):
+	def set_Marker(self, Marker):  # String
+		self.add_query_param('Marker', Marker)
+	def get_SetId(self): # String
 		return self.get_query_params().get('SetId')
 
-	def set_SetId(self,SetId):
-		self.add_query_param('SetId',SetId)
\ No newline at end of file
+	def set_SetId(self, SetId):  # String
+		self.add_query_param('SetId', SetId)
