@@ -25,32 +25,29 @@ class ListVideosRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ListVideos','imm')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Project(self):
+	def get_Project(self): # String
 		return self.get_query_params().get('Project')
 
-	def set_Project(self,Project):
-		self.add_query_param('Project',Project)
-
-	def get_Marker(self):
+	def set_Project(self, Project):  # String
+		self.add_query_param('Project', Project)
+	def get_Marker(self): # String
 		return self.get_query_params().get('Marker')
 
-	def set_Marker(self,Marker):
-		self.add_query_param('Marker',Marker)
-
-	def get_SetId(self):
+	def set_Marker(self, Marker):  # String
+		self.add_query_param('Marker', Marker)
+	def get_SetId(self): # String
 		return self.get_query_params().get('SetId')
 
-	def set_SetId(self,SetId):
-		self.add_query_param('SetId',SetId)
-
-	def get_CreateTimeStart(self):
+	def set_SetId(self, SetId):  # String
+		self.add_query_param('SetId', SetId)
+	def get_CreateTimeStart(self): # String
 		return self.get_query_params().get('CreateTimeStart')
 
-	def set_CreateTimeStart(self,CreateTimeStart):
-		self.add_query_param('CreateTimeStart',CreateTimeStart)
\ No newline at end of file
+	def set_CreateTimeStart(self, CreateTimeStart):  # String
+		self.add_query_param('CreateTimeStart', CreateTimeStart)
